import { createRouter, createWebHistory } from 'vue-router'
import VueCookies from 'vue-cookies'
import axios from 'axios'

const cookies = VueCookies

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('../views/ListView.vue')
    },
    {
      path: '/login',
      name: 'login',
      component: () => import('../views/LoginView.vue')
    },
    {
      path: '/edit',
      name: 'edit',
      component: () => import('../views/EditView.vue')
    },
    {
      path: '/404',
      name: '404',
      component: () => import('../views/404.vue')
    },
    {
      path: '/:lang([ch|en|all]+)/:page(\\d+)',
      name: 'list',
      component: () => import('../views/ListView.vue')
    },
    {
      path: '/page/:id(\\d+)',
      name: 'page',
      component: () => import('../views/ContentView.vue')
    },
    {
      path: '/page/:id(\\d+)/:para(\\d+)',
      name: 'comment',
      component: () => import('../views/ContentView.vue')
    },
    {
      path: '/:pathMatch(.*)*',
      redirect: '/404'
    }
  ]
})

function iscookieExist() {
  if (!cookies.isKey('TENZOR_AUTH')) {
    cookies.remove('TENZOR_AUTH');
  }

  cookies.set('TENZOR_AUTH', 'TEST');
  if (!cookies.isKey('TENZOR_AUTH')) {
    return true
  }
  else {
    cookies.remove('TENZOR_AUTH')
    return false
  }
}

function issessionExist() {
  if (sessionStorage.getItem('user_info') !== null) {
    return true
  }
  else {
    return false
  }
}

// cookies.remove('TENZOR_AUTH');
// // cookies.set('TENZOR_AUTH', "o29P-qxkMkWoDCSC4cqiDQjxTV0_7u527PDckR-mWNFL6BHVM6KyJepcMjmiwjG-ieL44wWJdo2oKHSlFgJwwR1ij1LaYajAMs4Pp-fRaZb8=")
// console.log(cookies.get('TENZOR_AUTH'))

router.beforeEach(async (to, from) => {
  // console.log(cookie)
  // console.log(iscookieExist(),issessionExist())
  if (iscookieExist()) { //有 cookie
    if (to.name === 'login') {
      return { name: 'home' }
    }
  }
  else {
    if (issessionExist()) {
      sessionStorage.removeItem('user_info')
    }
    if (to.name !== 'login') {
      return { name: 'login' }
    }
  }
})

export default router
